@@ -297,29 +297,43 @@ def get_wbt_dict(reset=False):
     return tools_dict
 
 
-def tool_gui(tool_dict, max_width="630px"):
+def tool_gui(tool_dict, max_width="420px", max_height="600px"):
     """Create a GUI for a tool based on the tool dictionary.
 
     Args:
         tool_dict (dict): The dictionary containing the tool info.
         max_width (str, optional): The max width of the tool dialog.
+        max_height (str, optional): The max height of the tool dialog.
 
     Returns:
         object: An ipywidget object representing the tool interface.
     """
-    tool_widget = widgets.VBox()
+    tool_widget = widgets.VBox(
+        layout=widgets.Layout(max_width=max_width, max_height=max_height)
+    )
     children = []
     args = {}
+    required_inputs = []
+    style = {"description_width": "initial"}
+    max_width = str(int(max_width.replace("px", "")) - 10) + "px"
 
-    header = widgets.Label(value=f'Current Tool: {tool_dict["name"]}')
-    spacer = widgets.Label(layout=widgets.Layout(width="50px"))
+    header_width = str(int(max_width.replace("px", "")) - 104) + "px"
+    header = widgets.Label(
+        value=f'Current Tool: {tool_dict["name"]}',
+        style=style,
+        layout=widgets.Layout(width=header_width),
+    )
     code_btn = widgets.Button(
         description="View Code", layout=widgets.Layout(width="100px")
     )
 
-    children.append(widgets.HBox([header, spacer, code_btn]))
+    children.append(widgets.HBox([header, code_btn]))
 
-    desc = widgets.Label(value=f'Description: {tool_dict["description"]}')
+    desc = widgets.Textarea(
+        value=f'Description: {tool_dict["description"]}',
+        layout=widgets.Layout(width="410px", max_width=max_width),
+        disabled=True,
+    )
     children.append(desc)
 
     params = tool_dict["parameters"]
@@ -328,6 +342,7 @@ def tool_gui(tool_dict, max_width="630px"):
         required = ""
         if items["optional"] == "false":
             required = "*"
+            required_inputs.append(param)
         label = items["name"] + required
         param_type = items["parameter_type"]
         default_value = None
@@ -340,7 +355,6 @@ def tool_gui(tool_dict, max_width="630px"):
             else:
                 default_value = items["default_value"].replace('"', "")
 
-        style = {"description_width": "initial"}
         layout = widgets.Layout(width="500px", max_width=max_width)
 
         if isinstance(param_type, str):
@@ -394,7 +408,7 @@ def tool_gui(tool_dict, max_width="630px"):
         description="Cancel", layout=widgets.Layout(width="100px")
     )
     help_btn = widgets.Button(description="Help", layout=widgets.Layout(width="100px"))
-    tool_output = widgets.Output(layout=widgets.Layout(max_height="300px"))
+    tool_output = widgets.Output(layout=widgets.Layout(max_height="200px"))
     children.append(widgets.HBox([run_btn, cancel_btn, help_btn]))
     children.append(tool_output)
     tool_widget.children = children
@@ -402,24 +416,38 @@ def tool_gui(tool_dict, max_width="630px"):
     def run_button_clicked(b):
         tool_output.clear_output()
 
+        required_params = required_inputs.copy()
         args2 = []
         for arg in args:
 
             line = ""
             if isinstance(args[arg], FileChooser):
+                if arg in required_params and args[arg].selected is None:
+                    with tool_output:
+                        print(f"Please provide inputs for required parameters.")
+                        break
+                elif arg in required_params:
+                    required_params.remove(arg)
                 if arg == "i":
                     line = f"-{arg}={args[arg].selected}"
                 else:
                     line = f"--{arg}={args[arg].selected}"
             elif isinstance(args[arg], widgets.Text):
+                if arg in required_params and len(args[arg].value) == 0:
+                    with tool_output:
+                        print(f"Please provide inputs for required parameters.")
+                        break
+                elif arg in required_params:
+                    required_params.remove(arg)
                 if args[arg].value is not None and len(args[arg].value) > 0:
                     line = f"--{arg}={args[arg].value}"
             elif isinstance(args[arg], widgets.Checkbox):
                 line = f"--{arg}={args[arg].value}"
             args2.append(line)
 
-        with tool_output:
-            wbt.run_tool(tool_dict["name"], args2)
+        if len(required_params) == 0:
+            with tool_output:
+                wbt.run_tool(tool_dict["name"], args2)
 
     def help_button_clicked(b):
         import webbrowser
@@ -442,7 +470,7 @@ def tool_gui(tool_dict, max_width="630px"):
     return tool_widget
 
 
-def build_toolbox(tools_dict, folder_icon="folder", tool_icon="wrench"):
+def build_toolbox_tree(tools_dict, folder_icon="folder", tool_icon="wrench"):
     """Build the toolbox for WhiteboxTools.
 
     Args:
@@ -457,16 +485,22 @@ def build_toolbox(tools_dict, folder_icon="folder", tool_icon="wrench"):
     right_widget = widgets.VBox()
     full_widget = widgets.HBox([left_widget, right_widget])
 
-    search_description = (
-        f"{len(tools_dict)} tools available. Enter a keyword to search ..."
-    )
+    search_description = f"{len(tools_dict)} tools available. Search tools ..."
     search_box = widgets.Text(placeholder=search_description)
-    search_box.layout.width = "310px"
+    search_box.layout.width = "270px"
+
+    close_btn = widgets.Button(icon="close", layout=widgets.Layout(width="32px"))
+
+    def close_btn_clicked(b):
+        full_widget.close()
+
+    close_btn.on_click(close_btn_clicked)
+
     tree_widget = widgets.Output()
     tree_widget.layout.max_width = "310px"
     tree_widget.overflow = "auto"
 
-    left_widget.children = [search_box, tree_widget]
+    left_widget.children = [widgets.HBox([search_box, close_btn]), tree_widget]
     output = widgets.Output(layout=widgets.Layout(max_width="760px"))
     right_widget.children = [output]
 
@@ -528,19 +562,37 @@ def build_toolbox(tools_dict, folder_icon="folder", tool_icon="wrench"):
     return full_widget
 
 
-def build_toolbox_lite(tools_dict):
+def build_toolbox(tools_dict, max_width="1080px", max_height="600px"):
+    """Build the toolbox for WhiteboxTools.
 
-    left_widget = widgets.VBox()
-    center_widget = widgets.VBox()
-    right_widget = widgets.Output(layout=widgets.Layout(width="630px"))
-    full_widget = widgets.HBox([left_widget, center_widget, right_widget])
+    Args:
+        tools_dict (dict): A dictionary containing information for all tools.
+        max_width (str, optional): The maximum width of the widget.
+        max_height (str, optional): The maximum height of the widget.
+
+    Returns:
+        object: An ipywidget representing the toolbox.
+    """
+    left_widget = widgets.VBox(layout=widgets.Layout(min_width="175px"))
+    center_widget = widgets.VBox(
+        layout=widgets.Layout(min_width="200px", max_width="200px")
+    )
+    right_widget = widgets.Output(
+        layout=widgets.Layout(width="630px", max_height=max_height)
+    )
+    full_widget = widgets.HBox(
+        [left_widget, center_widget, right_widget],
+        layout=widgets.Layout(max_width=max_width, max_height=max_height),
+    )
 
     search_widget = widgets.Text(
         placeholder="Search tools ...", layout=widgets.Layout(width="170px")
     )
     label_widget = widgets.Label(layout=widgets.Layout(width="170px"))
-    # search_widget.tooltip = "Search tools ..."
     label_widget.value = f"{len(tools_dict)} Available Tools"
+    close_btn = widgets.Button(
+        description="Close Toolbox", icon="close", layout=widgets.Layout(width="170px")
+    )
 
     categories = {}
     categories["All Tools"] = []
@@ -555,10 +607,10 @@ def build_toolbox_lite(tools_dict):
     all_tools = categories["All Tools"]
     all_tools.sort()
     category_widget = widgets.Select(
-        options=options, layout=widgets.Layout(width="170px", height="155px")
+        options=options, layout=widgets.Layout(width="170px", height="165px")
     )
     tools_widget = widgets.Select(
-        options=[], layout=widgets.Layout(width="270px", height="400px")
+        options=[], layout=widgets.Layout(width="195px", height="400px")
     )
 
     def category_selected(change):
@@ -577,7 +629,7 @@ def build_toolbox_lite(tools_dict):
             tool_dict = tools_dict[selected]
             with right_widget:
                 right_widget.clear_output()
-                display(tool_gui(tool_dict))
+                display(tool_gui(tool_dict, max_height=max_height))
 
     tools_widget.observe(tool_selected, "value")
 
@@ -598,9 +650,14 @@ def build_toolbox_lite(tools_dict):
 
     search_widget.observe(search_changed, "value")
 
+    def close_btn_clicked(b):
+        full_widget.close()
+
+    close_btn.on_click(close_btn_clicked)
+
     category_widget.value = list(categories.keys())[0]
     tools_widget.options = all_tools
-    left_widget.children = [category_widget, search_widget, label_widget]
+    left_widget.children = [category_widget, search_widget, label_widget, close_btn]
     center_widget.children = [tools_widget]
 
     return full_widget
@@ -616,13 +673,13 @@ def in_colab_shell():
         return False
 
 
-def show(verbose=True, reset=False, lite=False):
+def show(verbose=True, tree=False, reset=False):
     """Show the toolbox GUI.
 
     Args:
         verbose (bool, optional): Whether to show progress info when the tool is running. Defaults to True.
+        tree (bool, optional): Whether to use the tree mode toolbox built using ipytree rather than ipywidgets. Defaults to False.
         reset (bool, optional): Whether to regenerate the json file with the dictionary containing the information for all tools. Defaults to False.
-        lite (bool, optional): Whether to use a lite mode toolbox built using ipywidgets rather than ipytree. Defaults to False.
 
     Returns:
         object: A toolbox GUI.
@@ -635,10 +692,10 @@ def show(verbose=True, reset=False, lite=False):
         wbt.verbose = False
 
     if in_colab_shell():
-        lite = True
+        tree = False
 
-    if lite:
-        return build_toolbox_lite(tools_dict)
+    if tree:
+        return build_toolbox_tree(tools_dict)
     else:
         return build_toolbox(tools_dict)
 
